summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/kernel/tqprinter_unix.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/kernel/tqprinter_unix.cpp')
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqprinter_unix.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqprinter_unix.cpp b/experimental/tqtinterface/qt4/src/kernel/tqprinter_unix.cpp
index 047247949..80946867d 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqprinter_unix.cpp
+++ b/experimental/tqtinterface/qt4/src/kernel/tqprinter_unix.cpp
@@ -137,7 +137,7 @@ bool TQPrinter::cmd( int c, TQPainter *paint, TQPDevCmdParam *p )
//
// // try to replace this process with "true" - this prevents
// // global destructors from being called (that could possibly
// // do wrong things to the tqparent process)
// (void)execlp("true", "true", (char *)0);
// (void)execl("/bin/true", "true", (char *)0);
// (void)execl("/usr/bin/true", "true", (char *)0);
@@ -200,13 +200,13 @@ bool TQPrinter::cmd( int c, TQPainter *paint, TQPDevCmdParam *p )
// (void)execv( "/usr/bin/lpr", lprargs);
// }
// // if we couldn't exec anything, close the fd,
// // wait for a second so the tqparent process (the
// // child of the GUI process) has exited. then
// // exit.
// ::close( 0 );
// (void)::sleep( 1 );
// ::exit( 0 );
// } else { // tqparent process
// ::close( fds[0] );
// pdrv = new TQPSPrinter( this, fds[1] );
// state = PST_ACTIVE;
@@ -419,7 +419,7 @@ static void deleteGlobalPrinterDefaults()
}
/*!
- Opens a printer setup dialog, with tqparent \a tqparent, and asks the
+ Opens a printer setup dialog, with parent \a parent, and asks the
user to specify which printer they wish to use and what settings
it should have.
@@ -427,10 +427,10 @@ static void deleteGlobalPrinterDefaults()
user canceled the operation.
*/
-bool TQPrinter::setup( TQWidget * tqparent )
+bool TQPrinter::setup( TQWidget * parent )
{
#ifndef TQT_NO_PRINTDIALOG
- bool result = TQPrintDialog::getPrinterSetup( this, tqparent );
+ bool result = TQPrintDialog::getPrinterSetup( this, parent );
#else
bool result = FALSE;
#endif
@@ -556,7 +556,7 @@ bool TQPrinter::cmd( int c, TQPainter *paint, TQPDevCmdParam *p )
// try to replace this process with "true" - this prevents
// global destructors from being called (that could possibly
// do wrong things to the tqparent process)
(void)execlp("true", "true", (char *)0);
(void)execl("/bin/true", "true", (char *)0);
(void)execl("/usr/bin/true", "true", (char *)0);
@@ -619,13 +619,13 @@ bool TQPrinter::cmd( int c, TQPainter *paint, TQPDevCmdParam *p )
(void)execv( "/usr/bin/lpr", lprargs);
}
// if we couldn't exec anything, close the fd,
// wait for a second so the tqparent process (the
// child of the GUI process) has exited. then
// exit.
::close( 0 );
(void)::sleep( 1 );
::exit( 0 );
- } else { // tqparent process
+ } else { // parent process
::close( fds[0] );
pdrv = new TQPSPrinter( this, fds[1] );
state = PST_ACTIVE;
@@ -137,7 +137,7 @@ bool TQPrinter::cmd( int c, TQPainter *paint, TQPDevCmdParam *p )
// // try to replace this process with "true" - this prevents
// // global destructors from being called (that could possibly
-// // do wrong things to the tqparent process)
+// // do wrong things to the parent process)
// (void)execlp("true", "true", (char *)0);
// (void)execl("/bin/true", "true", (char *)0);
@@ -200,13 +200,13 @@ bool TQPrinter::cmd( int c, TQPainter *paint, TQPDevCmdParam *p )
// }
// // if we couldn't exec anything, close the fd,
-// // wait for a second so the tqparent process (the
+// // wait for a second so the parent process (the
// // child of the GUI process) has exited. then
// // exit.
@@ -200,13 +200,13 @@ bool TQPrinter::cmd( int c, TQPainter *paint, TQPDevCmdParam *p )
// (void)::sleep( 1 );
// ::exit( 0 );
-// } else { // tqparent process
+// } else { // parent process
// ::close( fds[0] );
// pdrv = new TQPSPrinter( this, fds[1] );
@@ -556,7 +556,7 @@ bool TQPrinter::cmd( int c, TQPainter *paint, TQPDevCmdParam *p )
// try to replace this process with "true" - this prevents
// global destructors from being called (that could possibly
- // do wrong things to the tqparent process)
+ // do wrong things to the parent process)
(void)execlp("true", "true", (char *)0);
(void)execl("/bin/true", "true", (char *)0);
@@ -619,13 +619,13 @@ bool TQPrinter::cmd( int c, TQPainter *paint, TQPDevCmdParam *p )
}
// if we couldn't exec anything, close the fd,
- // wait for a second so the tqparent process (the
+ // wait for a second so the parent process (the
// child of the GUI process) has exited. then
// exit.